Attribute VB_Name = "modStrFn"
Option Explicit


Public Function GetFirstName(strFullName As String) As String
'****************************************
'Sub/Function: GetFirstName
'
'Arguments: strFullName  A string representing a full name
'                        to validate
'
'Return:                 A string containing the First Name if the
'                        Full Name string is valid. If the Full Name
'                        string is invalid, the function returns the
'                        string, "ERROR"
'
'Remarks:                A valid string has only one space character
'
'Programmer: Bob Reselman
'
'
'Copyright 1998, Macmillan Publishing
'****************************************
    Dim lSpacePos As Long       'Position of space character
                                'in a string
    Dim strSpaceChar As String  'Space character
    Dim strFirstName As String  'Buffer for First Name string
    Dim lngResult As Long         'Result variable
    Dim lngLeftLen As Long        'Number of characters in First
                                'Name
 
    'Use the IsValid function to make sure that the
    'Full Name string has only one space character in it.
    If IsValid(strFullName) = False Then
        'If it doesn't, return the error string
        GetFirstName = "Error"
        'And exit the function
        Exit Function
    End If
 
    'Define space character
    strSpaceChar = " "
 
    'Find the position of the space character within the
    'full name string.
    lngResult = InStr(1, strFullName, strSpaceChar)
 
    'The position of the space character is also
    'the length to extract for the left side (First Name)
    lngLeftLen = lngResult
 
    'Extract the First Name and assign it to the
    'First Name variable
    strFirstName = Left(strFullName, lngLeftLen)
 
    'Return the value of the first name
    GetFirstName = strFirstName
End Function

Public Function GetLastName(strFullName As String) As String
'****************************************
'Sub/Function: GetLastName
'
'Arguments: strFullName  A string representing a full name
'                        to validate
'
'Return:                 A string containing the Last Name if the
'                        Full Name string is valid. If the Full Name
'                        string is invalid, the function returns the
'                        string, "ERROR"
'
'Remarks:                A valid string has only one space character
'
'Programmer: Bob Reselman
'
'
'Copyright 1998, Macmillan Publishing
'****************************************
    Dim lSpacePos As Long 'Position of space
                          'character in a string
    Dim strSpaceChar As String  'Space character
    Dim strLastName As String   'Buffer string
    Dim lngResult As Long       'Result variable
    Dim lRightLen As Long 'Num of chars in Last name
                             
 
    'Use the IsValid function to make sure that the
    'Full Name string has only one space character.
    If IsValid(strFullName) = False Then
        'If it doesn't, return the error string
        GetLastName = "Error"
        'And exit the function
        Exit Function
    End If
 
    'Define space character
    strSpaceChar = " "
 
    'Find the position of the space character
    lngResult = InStr(1, strFullName, strSpaceChar)
 
    'Define the number of characters to extracted
    'of the space character, (Last Name).
    'If you subtract the position of the space character for the total
    'number of characers in the Full Name string, this will yield the
    'number of characters to extract from the right hand side of the
    'Full Name string. Also, this technique avoids including the space
    'character itself by accident.
    lRightLen = Len(strFullName) - lngResult
 
    'Extract the right side of the Full Name string and assign
    'it to the Last Name Buffer
    strLastName = Right(strFullName, lRightLen)
 
    'Return the value of the Last Name string out of the function
    GetLastName = strLastName
End Function

Public Function IsValid(strFullName) As Boolean
'****************************************
'Sub/Function: IsValid
'
'Arguments: strFullName  A string representing a full name
'                        to validate
'
'Return:                 True, if the string has only 1 space
'                        character
'
'Remarks:                This function is used to deterine if
'                        more than one space character exists
'                        in a string.
'
'Programmer: Bob Reselman
'
'
'Copyright 1998, Macmillan Publishing
'****************************************
    
    Dim intSpaces  As Integer  'Hold the count of the
                        'number ofspaces in a string
    Dim intChars   As Integer  'Number of characters
    Dim intCntr    As Integer  'Counter variable
    Dim strSpace   As String   'The space character
    Dim strPresent As String   'A buffer to hold one
                               'characer to examine
    'Define the space character
    strSpace = " "
    
    'Find out how many characters are in the full name
    intChars = Len(strFullName)
    
    'Loop through the entire string, strFullName
    For intCntr = 1 To intChars
        'Look at each character one at a time
        strPresent = Mid$(strFullName, intCntr, 1)
        'If the character that you are inspecting is a
        'space....
        If strPresent = strSpace Then
            '...Increment the space counter variable by 1
            intSpaces = intSpaces + 1
        End If
    Next intCntr
    
    'if there is only one space in the Full Name string...
    If intSpaces = 1 Then
        '...return TRUE
        IsValid = True
    Else
        'If not, return false
        IsValid = False
    End If
End Function
